Rihanna at Alexander Wang, Adam Selman, and Altuzarra at New York Fashion Week: Glamour.com
Author: Glamour Magazine
Description: Oh, RiRi. You truly are an icon. When Rihanna walks into a fashion show, even editors, publicists, other celebs gasp. Gasp they did on Friday and Saturday as the cooler-than-thou-crooner sashayed into her costume designer Adam Selman's show, as well as those of Joseph Altuzarra and Alexander Wang. And she did not disappoint. Let's take a look at what she wore: At Adam Selman, RiRi rocked an elegant and girly white A-line dress with pearls and my favorite Christian Louboutin strappy pumps. For Altuzarra, she glammed out in super sophistication with a plunging black jacket with fringe from the designer's collection&#8212;WITHOUT PANTS. I LOVE IT. At Alexander Wang, she brought out her inner '90s child with a matching midnight blue hoodie and skirt. Are you a Rihhana fan? I love her. Now where's my plunging black jacket? Not to fret&#8212;I will wear pants.

Subscribe | Give a gift | Renew
Log in / Register Promos Hi Promos

- Logout
- Edit Profile

SUBSCRIBE

For Just $1.25 An Issue

SUBSCRIBE
Subscribe
Dressed

- #### prev story

  The Comfortable and Chic Evening Wear Trend Hot Off the Spring 2015 Runways

- #### next story

  Found at NYFW: The Best Way to Flatter Your Waist for Spring 2015 and Beyond

# Rihanna Leaves Pants at Home for Altuzarra Show, and We Love Her for It

By Sophia Chabbott
September 7, 2014

Oh, RiRi. You truly are an icon.

When Rihanna walks into a fashion show, even editors, publicists, other celebs gasp. Gasp they did on Friday and Saturday as the cooler-than-thou-crooner sashayed into her costume designer Adam Selman's show, as well as those of Joseph Altuzarra and Alexander Wang. And she did not disappoint. Let's take a look at what she wore:

At Adam Selman, RiRi rocked an elegant and girly white A-line dress with pearls and my favorite Christian Louboutin strappy pumps.

For Altuzarra, she glammed out in super sophistication with a plunging black jacket with fringe from the designer's collection—WITHOUT PANTS. I LOVE IT.

At Alexander Wang, she brought out her inner '90s child with a matching midnight blue hoodie and skirt.

Are you a Rihhana fan? I love her. Now where's my plunging black jacket? Not to fret—I will wear pants.

###### Photos: Getty Images

ADVERTISEMENT
Sophia Chabbott Senior online fashion editor, Alaïa enthusiast, collector of white button down shirts, shredded jean shorts, and huge fan of beach waves.
FOLLOW ME

#### Keywords:

- adam selman
- rihanna

## Recommended

## More Stories Like This

fashion The 5 New Ways To Style Pants That Will Rock Your World The 5 New Ways To Style Pants That Will Rock Your World
By Avery Matera
13 hours ago
fashion Over Glitter? Never. Glitter Shoes That Are Year-Round Approved Over Glitter? Never. 17 Glitter Shoes That Are Year-Round Approved
By Avery Matera
14 hours ago

## TRENDING

Princess Mary Had the Dreamiest New Year's Outfit, Ever
Is This the Most Sexist Relationship Advice Ever?
Huh? The Bra You're Supposed to Wear at Night (I Tried It!)